# pyleglight

A Python module designed to control the Elgato brand Lights. For automation or in lieu of their [Control Center app](https://www.elgato.com/en/gaming/downloads) (when on a non-supported platform)

## About the lights
As of this writing, the only compatible hardware is the [Elgato Key Light](https://www.elgato.com/en/gaming/key-light). This hardware operates on Wifi only, anounces itself on the network via [mDNS](https://en.wikipedia.org/wiki/Multicast_DNS) and is controllable via JSON [REST](https://en.wikipedia.org/wiki/Representational_state_transfer). As the lights are not-multicolored the only available controls are on/off, brightness, and [color temperature](https://en.wikipedia.org/wiki/Color_temperature#Categorizing_different_lighting) (from 3000k to 7000k)

## Examples
??

## License
MIT

## Copyright
Elgato, Key Light and other product names are copyright of their owner, CORSAIR. 